
//
//  @file Rcb4GetAd.ino
//  @brief RCB-4  Get AD program (Get Power Voltage)
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2018/01/30
//

////
////  RCB-4のAD0(電源電圧値)を取得します
////  
////  Digital 4pin
////  RCB-4の電源電圧が9.0V以下の時:L
////  RCB-4の電源電圧が9.0Vより大きい時:H
////
////　Digital 3pin 
////  H:通信成功
////  L:通信失敗


#include <Rcb4HardSerialClass.h> 

const byte ACK_CHECK_PIN = 3; 
const byte CHECK_PIN = 4;

const long BAUDRATE = 115200;
const int TIMEOUT = 100;

Rcb4HardSerialClass rcb4(&Serial,BAUDRATE,TIMEOUT);  //RCB4Classの定義、HardwareSerial版

void setup() {
  // put your setup code here, to run once:

  pinMode(ACK_CHECK_PIN ,OUTPUT);  //ACK確認を出力するピン設定
  pinMode(CHECK_PIN ,OUTPUT);   //AD値の判定を確認するピン設定
  
  if(rcb4.open() == true)       //通信設定およびconfigデータを取得
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }

  if(rcb4.checkAcknowledge() == true)   //Ackチェックは念のため
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }
}


///
/// 電源電圧に変換する(返り値は100倍した値)
///
int powerVoltage(unsigned short ad)
{
  if(0xFFFF == ad)  //通信失敗
  {
     return -1;
  }
  else 
  {
    //return (int)((long)ad * 2500 / 1024) ; 
    return (int)((long)ad * 2450 / 1024) ;   //電源電圧の約1/5(正確には10/49)がAD0に入力される 5V 10bitのAD変換値なので、　ad * 5 * (5/1024)
                                                     //それに100倍した値をかける
  }
}

void loop() {
  // put your main code here, to run repeatedly:

 unsigned short ad = rcb4.getAdData(0); //RCB4の電源電圧のAD値を取得
  if(ad == 0xffff)
  {//通信に失敗した場合
    digitalWrite(ACK_CHECK_PIN,LOW);
    digitalWrite(CHECK_PIN,LOW);
  }
  else
  {//通信に成功した場合
    digitalWrite(ACK_CHECK_PIN,HIGH);     //通信が成功した場合はACK_CHECK_PINをHに

    int vAd =  powerVoltage(ad);          //AD値を電圧値に変換
    
    if(vAd > 900)                         //9.0Vの判定
    {
      digitalWrite(CHECK_PIN,HIGH);
    }
    else
    {
      digitalWrite(CHECK_PIN,LOW);
    }
  }

  delay(100);
  
}
