
//
//  @file Rcb4MotionPlay.ino
//  @brief RCB-4 motion play sample program 
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2018/01/30
//

////
////  RCB-4内部に保存されているモーションを再生させます。
////  サンプルでは2秒毎にモーション1と2を繰り返します
////  モーションに関してはHTH4のVer2.2以降のモーションを書き込んでおきます

////  Digital 4pin
////  モーション再生失敗:L
////  モーション再生成功:H
////　Digital 3pin 
////  H:通信成功
////  L:通信失敗

#include <Rcb4HardSerialClass.h>

const byte ACK_CHECK_PIN = 3; 
const byte CHECK_PIN = 4;

const long BAUDRATE = 115200;
const int TIMEOUT = 100;

Rcb4HardSerialClass rcb4(&Serial,BAUDRATE,TIMEOUT);  //RCB4HardSerialClassの定義

void setup() {
  // put your setup code here, to run once:

  pinMode(ACK_CHECK_PIN ,OUTPUT);  //ACK確認を出力するピン設定
  pinMode(CHECK_PIN ,OUTPUT);   //確認を出力するピン設定
  digitalWrite(ACK_CHECK_PIN,LOW);

  rcb4.configData.word = 0xffff;  		//ConfigDataは間違えないように0xFFFFで初期化

  while(rcb4.open() == false);	//Configをとれないとモーション再生が大変なので、取得できるまでループ
  
  digitalWrite(ACK_CHECK_PIN,HIGH);		//OPENできていたらACKは返ってきている
  
  if(rcb4.checkAcknowledge() == true)		//ACKのチェック
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }
}

void loop() {
  // put your main code here, to run repeatedly:

  while(rcb4.configData.word == 0xffff);    //configDataが読み取れてない場合は無限ループ

  delay(2000);

  if(rcb4.motionPlay(1) == true)		//モーション1を再生
  {
     digitalWrite(CHECK_PIN,HIGH);
  }
  else						//通信失敗時
  {
     digitalWrite(CHECK_PIN,LOW);
  }
 
  delay(2000);

  if(rcb4.motionPlay(2) == true)		//モーション2を再生
  {
     digitalWrite(CHECK_PIN,HIGH);
  }
  else						//通信失敗時
  {
     digitalWrite(CHECK_PIN,LOW);
  }

}
 
