
//
//  @file Rcb4SetKrrButton.ino
//  @brief RCB-4 Krr button set sample program 
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2018/01/30
//

////
////  RCB-4にボタンデータを送ります
////  ※ボタンデータを送るとそのデータのままになります
////  ※ボタンデータを送る場合はKRRなど無線機ははずしてください
////  ↑(2秒),↓(2秒)、押さない状態(2秒)を繰り返し
////　Digital 3pin 
////  H:最初の通信成功
////  L:最初の通信失敗
////　Digital 4pin 
////  H:ボタンデータ送信成功(押さない状態時のみ)
////  L:ボタンデータ送信失敗(押さない状態時のみ)


#include <Rcb4HardSerialClass.h>

const byte ACK_CHECK_PIN = 3; 
const byte CHECK_PIN = 4;

const long BAUDRATE = 115200;
const int TIMEOUT = 100;

Rcb4HardSerialClass rcb4(&Serial,BAUDRATE,TIMEOUT);  //RCB4Classの定義、HardwareSerial版


void setup() {
  // put your setup code here, to run once:

  pinMode(ACK_CHECK_PIN ,OUTPUT);  //ACK確認を出力するピン設定
  pinMode(CHECK_PIN ,OUTPUT);   //確認を出力するピン設定

  while(rcb4.open() == false);  //Configをとれないとモーション再生が大変なので、取得できるまでループ

   digitalWrite(ACK_CHECK_PIN,HIGH);    //OPENできていたらACKは返ってきている
  
  if(rcb4.checkAcknowledge() == true)    //ACKのチェック
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }

}

void loop() {
  // put your main code here, to run repeatedly:

  rcb4.setKrrButtonData (rcb4.KRR_BUTTON_UP);     //↑ボタンの指示
  delay(2000);                                    //2s待つが、その間↑ボタンのまま
  rcb4.setKrrButtonData (rcb4.KRR_BUTTON_DOWN);   //↓ボタンの指示
  delay(2000);                                    //2s待つが、その間↓ボタンのまま
  
  if(rcb4.setKrrButtonData (rcb4.KRR_BUTTON_NONE) == true)  //送れたかどうかの合否判定付の書き方(何も押してない状態を送信)
  {
    digitalWrite(CHECK_PIN,HIGH);   //成功してたらCHECK_PINをHにする
  }
  else
  {
    digitalWrite(CHECK_PIN,LOW);    //失敗してたらCHECK_PINをLにする
  }
  delay(2000);
  
}
