
//
//  @file Rcb4GetAd.ino
//  @brief RCB-4  Get AD program (Get Power Voltage)
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2018/01/30
//

////
////  RCB-4のAD0(電源電圧値)を取得します
////  HeadSerial側に9600bpsで取得値を出力します
////  
////  Digital 4pin
////  RCB-4の電源電圧が9.0V以下の時:L
////  RCB-4の電源電圧が9.0Vより大きい時:H
////　Digital 3pin 
////  H:通信成功
////  L:通信失敗
////  

////


#include <Rcb4SoftSerialClass.h>

const byte ACK_CHECK_PIN = 3; 
const byte CHECK_PIN = 4;

const byte S_RX_PIN = 8;
const byte S_TX_PIN = 9;

const long BAUDRATE = 115200;
const int TIMEOUT = 100;


Rcb4SoftSerialClass rcb4(S_RX_PIN,S_TX_PIN,BAUDRATE,TIMEOUT);  //RCB4Classの定義、softSerial版

void setup() {
  // put your setup code here, to run once:

  pinMode(ACK_CHECK_PIN ,OUTPUT);  //ACK確認を出力するピン設定
  pinMode(CHECK_PIN ,OUTPUT);   //AD値の判定を確認するピン設定
  Serial.begin(9600);           //取得した値はシリアルに出力します 
  
  if(rcb4.open() == true)       //通信設定およびconfigデータを取得
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }

  if(rcb4.checkAcknowledge() == true)   //Ackチェックは念のため
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }
}


///
/// 電源電圧に変換する(返り値は100倍した値)
///
int powerVoltage(unsigned short ad)
{
  if(0xFFFF == ad)  //通信失敗
  {
     return -1;
  }
  else 
  {
    //return (int)((long)ad * 2500 / 1024) ;   
    return (int)((long)ad * 2450 / 1024) ;   //電源電圧の約1/5(正確には10/49)がAD0に入力される 5V 10bitのAD変換値なので、　ad * 5 * (5/1024)
                                                     //それに100倍した値をかける                                        
  }
}

void loop() {
  // put your main code here, to run repeatedly:

 unsigned short ad = rcb4.getAdData(0); //RCB4の電源電圧のAD値を取得
  if(ad == 0xffff)
  {//通信に失敗した場合
    digitalWrite(ACK_CHECK_PIN,LOW);
    digitalWrite(CHECK_PIN,LOW);
    Serial.write("AD = Null\r\n");
  }
  else
  {//通信に成功した場合
    digitalWrite(ACK_CHECK_PIN,HIGH);

    int vAd =  powerVoltage(ad);

    if(vAd > 900)
    {
      digitalWrite(CHECK_PIN,HIGH);
    }
    else
    {
      digitalWrite(CHECK_PIN,LOW);
    }
    Serial.write(" power[x100 V] = ");
    Serial.println(vAd,DEC);
  }

  delay(100);
  
}
