
//
//  @file Rcb4SetPio.ino
//  @brief RCB-4 set PIO sample program 
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2018/01/30
//
////
////  RCB-4のPIOを0.1秒毎順番にHにします
////　digital 3pin 
////  H:通信成功
////  L:通信失敗


#include <Rcb4SoftSerialClass.h>

const byte ACK_CHECK_PIN = 3; 
const byte CHECK_PIN = 4;

const byte S_RX_PIN = 8;
const byte S_TX_PIN = 9;

const long BAUDRATE = 115200;
const int TIMEOUT = 100;

Rcb4SoftSerialClass rcb4(S_RX_PIN,S_TX_PIN,BAUDRATE,TIMEOUT);  //RCB4Classの定義、softSerial版


void setup() {
  // put your setup code here, to run once:

  pinMode(ACK_CHECK_PIN ,OUTPUT);  //ACK確認を出力するピン設定
  
  if(rcb4.open() == true)          //OPENできていたらACKは返ってきている
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }

  if(rcb4.checkAcknowledge() == true)  //ACKのチェック
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }

  unsigned short setModeData = 0x03FF;  //すべて出力設定

  while(rcb4.setPioMode(setModeData));   //漏れがないように繰り返す
  

  
}

void loop() {
  // put your main code here, to run repeatedly:

  
  
  for(int i = 0;i<10;i++)                 //10bit分繰り返す
  {
    unsigned int setPioData =(0x0001<<i); //PIOを1bitシフトする

    if(rcb4.setPio(setPioData) == true)   //PIOにデータを送る,通信チェック
    {
      digitalWrite(ACK_CHECK_PIN,HIGH); 
    }
    else
    {
      digitalWrite(ACK_CHECK_PIN,LOW);
    }
    delay(100);
  }
  delay(100);


}
