
//
//  @file Rcb4SetServoParameter.ino
//  @brief RCB-4 chenge servo parameta sample program 
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2018/01/30
//

////
////  RCB-4とつながっているサーボモータのパラメータを変更します
////  SIO1-4 ID:1　=> speed
////  SIO5-8 ID:2  => strech
////  2秒おきに指定したstrech及びspeedを最大と最小にします
////  
////  ※サーボモータの登録はHeaetToHeartから行ってください
////　Digital 3pin 
////  H:スピード変更の通信が成功
////  L:スピード変更の通信が失敗
////　Digital 4pin 
////  H:ストレッチ変更の通信が成功
////  L:ストレッチ変更の通信が失敗


#include <Rcb4SoftSerialClass.h>

const byte SPEED_CHECK_PIN = 3; 
const byte STRECH_CHECK_PIN = 4;

const byte S_RX_PIN = 8;
const byte S_TX_PIN = 9;

const long BAUDRATE = 115200;
const int TIMEOUT = 100;


Rcb4SoftSerialClass rcb4(S_RX_PIN,S_TX_PIN,BAUDRATE,TIMEOUT);  //RCB4Classの定義、softSerial版

Rcb4BaseClass::ServoData servoStrechData[1];   //サーボのストレッチデータ群
Rcb4BaseClass::ServoData servoSpeedData[1];   //サーボのスピードデータ群

void setup() {
  // put your setup code here, to run once:

  pinMode(SPEED_CHECK_PIN ,OUTPUT);  //Speed変更を確認を出力するピン設定
  pinMode(STRECH_CHECK_PIN ,OUTPUT); //Strech変更を確認を出力するピン設定
  
  if(rcb4.open() == true)          //OPENできていたらACKは返ってきている
  {
    digitalWrite(SPEED_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(SPEED_CHECK_PIN,LOW);
  }

  if(rcb4.checkAcknowledge() == true)   //ACKのチェック
  {
    digitalWrite(STRECH_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(STRECH_CHECK_PIN,LOW);
  }

  ///
  /// 初期設定を入れておく
  /// ServoData型：ID,SIO,Data
  ///
  servoStrechData[0].Id = 2;
  servoStrechData[0].Sio =rcb4.SIO5_8;
  servoSpeedData[0].Id = 1;
  servoSpeedData[0].Sio =rcb4.SIO1_4;
  
}

void loop() {
  // put your main code here, to run repeatedly:

  servoStrechData[0].Data = 1;    //ストレッチを1に
  servoSpeedData[0].Data = 1;     //スピードを1に
  
  rcb4.setServoSpeed(servoSpeedData,1);   //指定したサーボモータのスピードを変更する　ServoData配列、配列数
  rcb4.setServoStretch(servoStrechData,1);//指定したサーボモータのスピードを変更する  ServoData配列、配列数
  
  delay(2000);


  servoStrechData[0].Data = 127;    //ストレッチを127に
  servoSpeedData[0].Data = 127;     //スピードを127に
  
  
  ///
  /// 通信合否付
  ///
  if(rcb4.setServoSpeed(servoSpeedData,1) == true)  //指定したサーボモータのスピードを変更する
  {
    digitalWrite(SPEED_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(SPEED_CHECK_PIN,LOW);
  }
  
  if(rcb4.setServoStretch(servoStrechData,1) == true) //指定したサーボモータのスピードを変更する
  {
    digitalWrite(STRECH_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(STRECH_CHECK_PIN,LOW);
  }
  
  
  delay(2000);

  

  
}
