
//
//  @file Rcb4SetServoPos.ino
//  @brief RCB-4  many Servomotors move sample program 
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2018/01/30
//

////
////  RCB-4とつながっているサーボモータを1秒おきに動かします
////  角度指令 => (1s) => 角度指令 => (1s) => Free => (1s) => Hold => (1s)......... 
////  SIO1-4 ID:1
////  SIO5-8 ID:2 
////  ※サーボモータの登録はHeaetTo Heartから行ってください
////　Digital 3pin 
////  H:通信成功
////  L:通信失敗

#include <Rcb4SoftSerialClass.h>

const byte ACK_CHECK_PIN = 3; 

const byte S_RX_PIN = 8;
const byte S_TX_PIN = 9;

const long BAUDRATE = 115200;
const int TIMEOUT = 100;

Rcb4SoftSerialClass rcb4(S_RX_PIN,S_TX_PIN,BAUDRATE,TIMEOUT);  //RCB4Classの定義、softSerial版


Rcb4BaseClass::ServoData servoData[2];   //サーボのデータ群

void setup() {
  // put your setup code here, to run once:

  pinMode(ACK_CHECK_PIN ,OUTPUT);  //ACK確認を出力するピン設定
    
  if(rcb4.open() == true)         //OPENできていたらACKは返ってきている
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }

  if(rcb4.checkAcknowledge() == true) //ACKのチェック
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }
  
  ///
  /// 初期設定を入れておく
  /// ServoData型：ID,SIO,Data
  ///
  servoData[0].Id = 2;
  servoData[0].Sio =rcb4.SIO5_8;
  servoData[1].Id = 1;
  servoData[1].Sio =rcb4.SIO1_4;
  
  
}

void loop() {
  // put your main code here, to run repeatedly:

  servoData[0].Data = 9500;
  servoData[1].Data = 5500;
  
  rcb4.setServoPos (servoData,2,50);    //指定したサーボモータの角度を変更する　ServoData配列、配列数、フレーム数
  
  delay(1000);
  
  servoData[0].Data = 7500;
  servoData[1].Data = 7500;
  
  ///
  /// 通信合否付
  ///
  if(rcb4.setServoPos (servoData,2,5) == true)  //指定したサーボモータの角度を変更する　ServoData配列、配列数、フレーム数
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }
  
  delay(1000);

  //フリーにもできます
  rcb4.setFreePos(servoData,2);   //指定したサーボモータをフリーにする　ServoData配列、配列数

  delay(1000);
  
  //フリーから復帰します
  rcb4.setHoldPos(servoData,2); //指定したサーボモータにトルクをかける　ServoData配列、配列数

  delay(1000);
}
