
//
//  @file Rcb4SetSingleServo.ino
//  @brief RCB-4  one servomotor move sample program 
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2018/01/30
//

////
////  RCB-4とつながっているサーボモータを単独動作で動かします
////  SIO1-4 ID:1
////  SIO5-8 ID:2 
////  ※サーボモータの登録はHeaetToHeartから行ってください
////　digital 3pin 
////  H:通信成功
////  L:通信失敗

#include <Rcb4SoftSerialClass.h>

const byte ACK_CHECK_PIN = 3; 

const byte S_RX_PIN = 8;
const byte S_TX_PIN = 9;

const long BAUDRATE = 115200;
const int TIMEOUT = 100;

Rcb4SoftSerialClass rcb4(S_RX_PIN,S_TX_PIN,BAUDRATE,TIMEOUT);  //RCB4Classの定義、softSerial版


void setup() {
  // put your setup code here, to run once:

  pinMode(ACK_CHECK_PIN ,OUTPUT);  //ACK確認を出力するピン設定
  
  if(rcb4.open() == true)   //OPENできていたらACKは返ってきている
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }

  if(rcb4.checkAcknowledge() == true)   //ACKのチェック
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }
}

void loop() {
  // put your main code here, to run repeatedly:


  //
  //  ※実際には内部で設定されているトリムも値が付加されたものが最終出力になります。
  //
  rcb4.setSingleServo (2, rcb4.SIO5_8,9500,50);   //SIO5-8のID:2を50フレームで9500にする
  delay(1000);

  //フリーにもできます
  rcb4.setFreeSingleServo (2, rcb4.SIO5_8);       //SIO5-8のID:2をフリーに
  delay(1000);

  
  rcb4.setSingleServo (1, rcb4.SIO1_4,5500,50);   //SIO1-4のID:1を50フレームで5500にする
  delay(1000);

    
  //フリーから復帰します
  rcb4.setHoldSingleServo (2, rcb4.SIO5_8);       //SIO5-8のID:2をホールドに
  delay(1000);
  

  ///
  /// 通信合否付
  ///
  if(rcb4.setSingleServo (2, rcb4.SIO5_8,7500,5) == true) //SIO5-8のID:2を50フレームで9500にする
  {
   
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    
    digitalWrite(ACK_CHECK_PIN,LOW);
  }
 
 delay(400);
 
  if( rcb4.setSingleServo (1, rcb4.SIO1_4,7500,5) == true) //SIO1-4のID:1を5フレームで7500にする
  {
    
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    
    digitalWrite(ACK_CHECK_PIN,LOW);
  }
     
 delay(400);
 

}
