
//
//  @file Rcb4GetAd.ino
//  @brief RCB-4  Get PIO program 
//  @author Kondo Kagaku Co.,Ltd.
//  @date 2018/01/30
//

////
////  RCB-4の現在のPIO1を取得しDigital4Pinに出力します
////　digital 3pin 
////  H:通信成功
////  L:通信失敗


#include <Rcb4SoftSerialClass.h>

const byte ACK_CHECK_PIN = 3; 
const byte CHECK_PIN = 4;

const byte S_RX_PIN = 10;
const byte S_TX_PIN = 11;

const long BAUDRATE = 115200;
const int TIMEOUT = 100;


Rcb4SoftSerialClass rcb4(S_RX_PIN,S_TX_PIN,BAUDRATE,TIMEOUT);  //RCB4Classの定義、softSerial版

void setup() {
  // put your setup code here, to run once:

  pinMode(ACK_CHECK_PIN ,OUTPUT);  //ACK確認を出力するピン設定
  pinMode(CHECK_PIN ,OUTPUT);   //確認を出力するピン設定
  
  if(rcb4.open() == true)      //通信設定およびconfigデータを取得
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }

  if(rcb4.checkAcknowledge() == true)   //Ackチェックは念のため
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,LOW);
  }

  //PIO1にあたるPINを入力にする。それ以外は出力
  unsigned short setModeData = 0xFFFE;   //1：出力、0:入力　0b111111 11111110
  while(rcb4.setPioMode(setModeData));   //漏れがないように繰り返す
  
  
}

void loop() {
  // put your main code here, to run repeatedly:

  unsigned short  pio = rcb4.getPio();
  if(pio == 0xffff)
  {//ｴﾗｰ
    digitalWrite(ACK_CHECK_PIN,LOW);
    digitalWrite(CHECK_PIN,LOW);
  }
  else
  {
    digitalWrite(ACK_CHECK_PIN,HIGH);
    digitalWrite(CHECK_PIN, pio & 0x0001 ? HIGH:LOW);   //PIO1がHの時Digital4にHを出力
    
  }
  delay(100);
}
